@@ -28,7 +28,7 @@ class ChangeTypes(enum.Enum):
         for item in ChangeTypes:
             if item.tag.lower() == tag.lower():
                 return item
-        raise UnsupportedTagException(f'Tag "{tag}" not supported!')
+        raise UnsupportedTagException(f'Tag "{tag}" not supported! Supported tags = {ChangeTypes.accept_tag()}')
 
     @staticmethod
     def accept_tag() -> List[str]:
